# Copyright 2024-2025 Sébastien Demanou. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from typing import Literal

from pydantic import BaseModel
from pydantic import Field

from .document import BaseMeta
from .document import Document
from .location import ComputedLocation


class User(BaseModel):
  email: str
  firstname: str
  lastname: str
  gender: Literal['male', 'female'] | None = None
  address: str | None = None
  birthdate: str | None = None
  phone: str | None = None
  devices: list[str] = Field(default_factory=list)


class RegisterPayload(User, BaseModel):
  password: str


UserDocumentType = Document[User, ComputedLocation, BaseMeta]
UserDocument = UserDocumentType.create_alias_from_base_meta(
  data_cls=User,
  computed_cls=ComputedLocation,
)
